summaryrefslogtreecommitdiffstats
path: root/kverbos/kverbos/verbspanish.h
diff options
context:
space:
mode:
Diffstat (limited to 'kverbos/kverbos/verbspanish.h')
-rw-r--r--kverbos/kverbos/verbspanish.h74
1 files changed, 37 insertions, 37 deletions
diff --git a/kverbos/kverbos/verbspanish.h b/kverbos/kverbos/verbspanish.h
index 8b7cf7b1..f621718d 100644
--- a/kverbos/kverbos/verbspanish.h
+++ b/kverbos/kverbos/verbspanish.h
@@ -19,7 +19,7 @@
#define VERBSPANISH_H
// include qt-Header
-#include <qvaluelist.h>
+#include <tqvaluelist.h>
#define MAX_TIEMPOS 9
#define MAX_SUBTYPES 3
@@ -41,8 +41,8 @@ enum timeTypes {presente, imperfecto, indefinido, futuro, condicional, subPresen
enum timeSubTypes {normal, progresivo, perfecto};
enum persons {yo, tu, el, nosotros, vosotros, ellos};
-typedef QString formArray[MAX_TIEMPOS][PERSONEN];
-typedef QString endingsArray[MAX_TIEMPOS][VERBMUSTER][PERSONEN];
+typedef TQString formArray[MAX_TIEMPOS][PERSONEN];
+typedef TQString endingsArray[MAX_TIEMPOS][VERBMUSTER][PERSONEN];
/** This class contains all the information belonging to one verb:
*
@@ -93,13 +93,13 @@ typedef QString endingsArray[MAX_TIEMPOS][VERBMUSTER][PERSONEN];
* The conjugated forms of the verb are stored in the array 'formArray'. The first index
* mentions the time and the second the person.
* <pre>
- * typedef QString formArray[MAX_TIEMPOS][PERSONEN];
+ * typedef TQString formArray[MAX_TIEMPOS][PERSONEN];
* </pre>
*
* The type 'endingsArray' stores the different endings. The first index means the time,
* the second the type of verb (-ar, -er, -ir) and the lase one is the person.
* <pre>
- * typedef QString endingsArray[MAX_TIEMPOS][MAX_SUBTYPES][PERSONEN];
+ * typedef TQString endingsArray[MAX_TIEMPOS][MAX_SUBTYPES][PERSONEN];
* </pre>
*
* The verbs are divided in several groups:
@@ -132,10 +132,10 @@ public:
verbSpanish& operator= (const verbSpanish& v);
/** If two verbs are compared only the foreign form and the spanish form are compared */
bool operator== (const verbSpanish& v) const;
/** This overloaded == operator compares the verb to a QString.
* Only the spanish meaning is compared.
*/
- bool operator== (const QString& s) const;
+ bool operator== (const TQString& s) const;
/** The spa/nisch forms of the verb are compared */
bool operator< (const verbSpanish& v) const;
/** Compares the verb objects completely, all forms and fields.
@@ -146,28 +146,28 @@ public:
bool isEmpty() const;
/** returns the foreign meaning of the verb
*/
- QString getForeign() const;
+ TQString getForeign() const;
/** sets the foreign meaning of the verb
*/
- void setForeign(const QString &s);
+ void setForeign(const TQString &s);
/** returns the spanish meaning of the verb
*/
- QString getSpanish() const;
+ TQString getSpanish() const;
/** sets the spanish meaning of the verb
*/
- void setSpanish(const QString &s);
+ void setSpanish(const TQString &s);
/** returns the gerund of the verb
*/
- QString getGerund();
+ TQString getGerund();
/** sets the gerund form to the string given in s
*/
- void setGerund(const QString &s);
+ void setGerund(const TQString &s);
/** returns the particip of the verb
*/
- QString getPartizip();
+ TQString getPartizip();
/** sets the participe to the string given in s
*/
- void setPartizip(const QString &s);
+ void setPartizip(const TQString &s);
/** returns if the verb belongs to one of the groups
*/
bool isGroupVerb();
@@ -186,13 +186,13 @@ public:
* parts[2] the verb form
* The return value 'bool' indicates if the form could be formed.
*/
- bool getForm(int t, int p, int typ, QString parts[]);
+ bool getForm(int t, int p, int typ, TQString parts[]);
/** returns the desired verb form indicated by time and person as a string
*/
- QString getForm(int t, int p);
+ TQString getForm(int t, int p);
/** sets the verb form that is indicated by time and person
*/
- void setForm(int t, int p, QString s);
+ void setForm(int t, int p, TQString s);
/** The following function generates the regular verb forms. The forms can be
* generated time by time or all times in one step by using conjugateAll()
*/
@@ -202,9 +202,9 @@ public:
bool isReflexiv() const;
/** returns the reflexive pronoun that belongs to the person p
*/
- QString getRefPron(int p);
+ TQString getRefPron(int p);
/** tests if the string is an automatic generated Form, that means the last char is '#' */
- bool isAutoForm(QString& s) const;
+ bool isAutoForm(TQString& s) const;
private:
bool conjugatePresente();
bool conjugateImperfecto();
@@ -216,7 +216,7 @@ private:
bool conjugateImperativo();
/** returns the verb stem
*/
- QString getStem() const;
+ TQString getStem() const;
/** returns the ending of the verb
*/
endings getEnding(bool& good);
@@ -226,7 +226,7 @@ private:
* bereits eine gültige Form vorliegt und diese Form eine unregelmäßige Form ist, die
* nicht überschrieben werden soll.
*/
- bool conjugateTime(const int t, const QString &s);
+ bool conjugateTime(const int t, const TQString &s);
/** Es wird verglichen, ob die beiden Strings gemeinsame Bestandteile haben. Also
* "gehen, laufen, springen" wird etwa mit "gehen, laufen" verglichen. Die Funktion
* gibt in so einem Fall 'true' zurück, auch wenn im zweiten String ein Teil
@@ -234,24 +234,24 @@ private:
* mehr oder weniger deutsche Bedeutungen oder die Bedeutungen in anderer Reihenfolge
* angegeben sind.
*/
- bool vergleich(const QString& s1, const QString& s2) const;
+ bool vergleich(const TQString& s1, const TQString& s2) const;
/** Deletes the '#' character from autogenerated forms. */
- QString delAutoForm(QString s) const;
+ TQString delAutoForm(TQString s) const;
/** does the changes for group verbs
*/
- bool groupVerb(QString &s, int time=-1, int person=-1);
+ bool groupVerb(TQString &s, int time=-1, int person=-1);
/** the verb in the foreign language
*/
- QString foreign;
+ TQString foreign;
/** the spanish verb
*/
- QString spanish;
+ TQString spanish;
/** the gerund form of the verb
*/
- QString gerund;
+ TQString gerund;
/** the partizip form of the verb
*/
- QString partizip;
+ TQString partizip;
/** the array for all the different forms of the verb
*/
formArray forms;
@@ -270,32 +270,32 @@ private:
static endingsArray verbEndings;
/** the reflexive pronouns
*/
- static QString refPron[PERSONEN];
+ static TQString refPron[PERSONEN];
public:
/** The forms of the verb estar. They are needed for the gerund form.
*/
- static QString estar[MAX_TIEMPOS][PERSONEN];
+ static TQString estar[MAX_TIEMPOS][PERSONEN];
/** The forms of the verb haber. They are needed for perfect forms
*/
- static QString haber[MAX_TIEMPOS][PERSONEN];
+ static TQString haber[MAX_TIEMPOS][PERSONEN];
/** This array contains the names of the time forms as strings
*/
- static QString timeNames[MAX_TIEMPOS*MAX_SUBTYPES];
+ static TQString timeNames[MAX_TIEMPOS*MAX_SUBTYPES];
/** This array contains the names of the different verb groups
*/
- static QString groupNames[MAX_GRUPPEN];
+ static TQString groupNames[MAX_GRUPPEN];
static int maxTiempos;
static int maxSubtypes;
static int persons;
static int maxForms;
/** The language that is selected at the moment. This selection affects all the instances
* of the class. */
- static QString language;
+ static TQString language;
};
/** Very often a list of verbs is needed. This is the type definition of a
* QValueList template with the verbSpanish type
*/
-typedef QValueList<verbSpanish> spanishVerbList;
+typedef TQValueList<verbSpanish> spanishVerbList;
#endif
@@ -132,10 +132,10 @@ public:
/** If two verbs are compared only the foreign form and the spanish form are compared */
bool operator== (const verbSpanish& v) const;
- /** This overloaded == operator compares the verb to a QString.
+ /** This overloaded == operator compares the verb to a TQString.
* Only the spanish meaning is compared.
*/
@@ -270,32 +270,32 @@ private:
};
/** Very often a list of verbs is needed. This is the type definition of a
- * QValueList template with the verbSpanish type
+ * TQValueList template with the verbSpanish type
*/